@@ -7,10 +7,13 @@ def main():
     
     home = os.path.expanduser("~")
     
-    rubydir = "{}/Library/Preferences/RubyMine60".format(home)
+    rubydir = "{}/Library/Preferences/RubyMine70".format(home)
+    if not os.path.exists(rubydir):
+        rubydir = "{}/Library/Preferences/RubyMine60".format(home)
+        
     if not os.path.exists(rubydir):
         rubydir = "{}/Library/Preferences/RubyMine50".format(home)
-        print("You might want to upgrade to RubyMine 6.0...")
+        print("You might want to upgrade to RubyMine 6.0 or 7.0...")
     
     tools = "{}/tools/GUS.xml".format(rubydir)
     
